# goto.py

This package allows you to go back to a certain line.

## Installation

Stable version:

```
pip install goto-py
```

Development version:

```
pip install git+https://github.com/Kev-in123/goto-py
```

## Example Usage

```python
from goto-py import goto
print("hi")
goto(2)
```